REM =================================================================
REM fsrm     collecting FSRM drivers trace.
REM =================================================================
REM 3201C659-D580-4833-B17D-1ADAF643C64C => FSRM Tracing Provider
REM 1214600F-DF79-4A03-94F5-65D7CAB4FD16 => Quota
REM DB4A5343-AC92-4B83-9D84-7ED8FADD7AA5 => Datascrn
REM 1C7BC728-8199-48BE-BD4D-406A63303C8D => Cbafilt
REM F3C5E28E-63F6-49C7-A204-E48A1BC4B09D => filter manager
REM =================================================================
REM arg1 = start or stop.
REM arg2 = output dir.
REM arg3 = Maximum log file size in MB
REM arg4 = if boot mode is selected. (autosession\)

SETLOCAL ENABLEDELAYEDEXPANSION
for /f "usebackq tokens=*" %%i in (`powershell Get-Date -Format "yyyy-MMdd-HHmmss"`) do @set logdate=%%i
set tracelogdir=%2
set maxsize=%3
set boot=%4

if /i "%1" =="start" (

   logman fsrm_trace -ets > NUL 2>&1
   if !ERRORLEVEL! EQU 0 goto DEP

   ECHO Log folder is %tracelogdir%.
   ECHO Log size is %maxsize%.
   logman create trace "%boot%fsrm_trace" -ow -o %tracelogdir%\%COMPUTERNAME%_fsrm_trace_%logdate%.etl -p {3201C659-D580-4833-B17D-1ADAF643C64C} 0xffffffffffffffff 0xff -nb 16 16 -bs 1024 -mode Circular -f bincirc -max %maxsize% -ets
   logman create trace "%boot%quota_trace" -ow -o %tracelogdir%\%COMPUTERNAME%_quota_trace_%logdate%.etl -p {1214600F-DF79-4A03-94F5-65D7CAB4FD16} 0xffffffffffffffff 0xff -nb 16 16 -bs 1024 -mode Circular -f bincirc -max %maxsize% -ets
REM 
REM datascrn is disabled for a while because it does not work.
REM
REM   logman create trace "%boot%datascrn_trace" -ow -o %tracelogdir%\d%COMPUTERNAME%_atascrn_trace_%logdate%.etl -p {DB4A5343-AC92-4B83-9D84-7ED8FADD7AA5} 0xffffffffffffffff 0xff -nb 16 16 -bs 1024 -mode Circular -f bincirc -max 4096 -ets
   logman create trace "%boot%cbafilt_trace" -ow -o %tracelogdir%\%COMPUTERNAME%_cbafilt_trace_%logdate%.etl -p {1C7BC728-8199-48BE-BD4D-406A63303C8D} 0xffffffffffffffff 0xff -nb 16 16 -bs 1024 -mode Circular -f bincirc -max %maxsize% -ets
   logman create trace "%boot%filtermgr_trace" -ow -o %tracelogdir%\%COMPUTERNAME%_filtermgr_trace_%logdate%.etl -p {F3C5E28E-63F6-49C7-A204-E48A1BC4B09D} 0xffffffffffffffff 0xff -nb 16 16 -bs 1024 -mode Circular -f bincirc -max %maxsize% -ets

   if DEFINED boot (
      reg add HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\WMI\Autologger\fsrm_trace /v FileName /t REG_SZ /d "%tracelogdir%\%COMPUTERNAME%_boot_fsrm_trace.etl" /f
      reg add HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\WMI\Autologger\quota_trace /v FileName /t REG_SZ /d "%tracelogdir%\%COMPUTERNAME%_boot_quota_trace.etl" /f
REM      reg add HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\WMI\Autologger\datascrn_trace /v FileName /t REG_SZ /d "%tracelogdir%\%COMPUTERNAME%_boot_datascrn_trace.etl" /f
      reg add HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\WMI\Autologger\cbafilt_trace /v FileName /t REG_SZ /d "%tracelogdir%\%COMPUTERNAME%_boot_cbafilt_trace.etl" /f
      reg add HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\WMI\Autologger\filtermgr_trace /v FileName /t REG_SZ /d "%tracelogdir%\%COMPUTERNAME%_boot_filtermgr_trace.etl" /f

   )
   exit /b
) else if /i "%1" =="stop" (

   logman fsrm_trace -ets > NUL 2>&1
   if !ERRORLEVEL! EQU 0 (
      for /f "tokens=3 usebackq delims= " %%i in (`logman fsrm_trace -ets ^| findstr "Output Location"`) do (
         echo Logfile is %%i
      )
      logman stop "fsrm_trace" -ets

      for /f "tokens=3 usebackq delims= " %%i in (`logman quota_trace -ets ^| findstr "Output Location"`) do (
         echo Logfile is %%i
      )
      logman stop "quota_trace" -ets
REM   logman stop "datascrn_trace" -ets

      for /f "tokens=3 usebackq delims= " %%i in (`logman cbafilt_trace -ets ^| findstr "Output Location"`) do (
         echo Logfile is %%i
      )
      logman stop "cbafilt_trace" -ets

      for /f "tokens=3 usebackq delims= " %%i in (`logman filtermgr_trace -ets ^| findstr "Output Location"`) do (
         echo Logfile is %%i
      )
      logman stop "filtermgr_trace" -ets
   )
   if DEFINED boot (
      logman delete "%boot%fsrm_trace"
      logman delete "%boot%quota_trace"
REM      logman delete "%boot%datascrn_trace"
      logman delete "%boot%cbafilt_trace"
      logman delete "%boot%filtermgr_trace"
   )
   echo Tracing has been stopped.
   exit /b
) else (
   goto USAGE
)

:DEP
   ECHO fsrm_trace has already been started.
exit /b

:USAGE
   ECHO   fsrm     collecting FSRM drivers trace.
   ECHO   shacollector.bat trace fsrm start size [Maximum log file size in MB (default 4096 MB)] [output folder (default c:\mslog)]
   ECHO   shacollector.bat trace fsrm stop
   ECHO   Boot Option:
   ECHO   shacollector.bat trace fsrm boot size [Maximum log file size in MB (default 4096 MB)] [output folder (default c:\mslog)]
   ECHO   shacollector.bat trace fsrm delete
exit /b