REM =================================================================
REM network   collecting Network driver trace.
REM =================================================================
REM DD7A21E6-A651-46D4-B7C2-66543067B869 => NDISTraceGuid
REM eb004a05-9b1a-11d4-9123-0050047759bc => NETIO
REM E53C6823-7BB8-44BB-90DC-3F86090D48A6 => Microsoft-Windows-Winsock-AFD
REM 2F07E2EE-15DB-40F1-90EF-9D7BA282188A => Microsoft-Windows-TCPIP
REM B40AEF77-892A-46F9-9109-438E399BB894 => AFD Trace
REM =================================================================
REM arg1 = start or stop.
REM arg2 = output dir.
REM arg3 = Maximum log file size in MB
REM arg4 = if boot mode is selected. (autosession\)

SETLOCAL ENABLEDELAYEDEXPANSION
for /f "usebackq tokens=*" %%i in (`powershell Get-Date -Format "yyyy-MMdd-HHmmss"`) do @set logdate=%%i
set tracelogdir=%2
set maxsize=%3
set boot=%4

if /i "%1" =="start" (
   logman network_trace -ets > NUL 2>&1
   if !ERRORLEVEL! EQU 0 goto DEP

   ECHO Log folder is %tracelogdir%.
   ECHO Log size is %maxsize%.
   logman create trace "%boot%network_trace" -ow -o %tracelogdir%\%COMPUTERNAME%_network_trace_%logdate%.etl -p {DD7A21E6-A651-46D4-B7C2-66543067B869} 0xffffffffffffffff 0xff -nb 16 16 -bs 1024 -mode Circular -f bincirc -max %maxsize% -ets
   logman update trace "%boot%network_trace" -p {eb004a05-9b1a-11d4-9123-0050047759bc} 0xffffffffffffffff 0xff -ets
   logman update trace "%boot%network_trace" -p {E53C6823-7BB8-44BB-90DC-3F86090D48A6} 0xffffffffffffffff 0xff -ets
   logman update trace "%boot%network_trace" -p {2F07E2EE-15DB-40F1-90EF-9D7BA282188A} 0xffffffffffffffff 0xff -ets
   logman update trace "%boot%network_trace" -p {B40AEF77-892A-46F9-9109-438E399BB894} 0xffffffffffffffff 0xff -ets

   if DEFINED boot (
      reg add HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\WMI\Autologger\network_trace /v FileName /t REG_SZ /d "%tracelogdir%\%COMPUTERNAME%_boot_network_trace.etl" /f
   )
   exit /b
) else if /i "%1" =="stop" (
   logman network_trace -ets > NUL 2>&1
   if !ERRORLEVEL! EQU 0 (
      for /f "tokens=3 usebackq delims= " %%i in (`logman network_trace -ets ^| findstr "Output Location"`) do (
         echo Logfile is %%i
      )
      logman stop "network_trace" -ets
   )
   if DEFINED boot (
      logman delete "%boot%network_trace"
   )
   echo Tracing has been stopped.
   exit /b
) else (
   goto USAGE
)

:DEP
   ECHO network_trace has already been started.
exit /b

:USAGE
   ECHO   network   collecting Network driver trace.
   ECHO   shacollector.bat trace network start size [Maximum log file size in MB (default 4096 MB)] [output folder (default c:\mslog)]
   ECHO   shacollector.bat trace network stop
   ECHO   Boot Option:
   ECHO   shacollector.bat trace network boot size [Maximum log file size in MB (default 4096 MB)] [output folder (default c:\mslog)]
   ECHO   shacollector.bat trace network delete
exit /b