REM =================================================================
REM ntfs   collecting ntfs driver trace.
REM =================================================================
REM B2FC00C4-2941-4D11-983B-B16E8AA4E25D => NtfsLog
REM DD70BC80-EF44-421B-8AC3-CD31DA613A4E => Ntfs
REM E9B319E4-0030-40A7-91CB-04D6A8EF7E09 => Microsoft-Windows-Ntfs-SQM
REM 8E6A5303-A4CE-498F-AFDB-E03A8A82B077 => Microsoft-Windows-Ntfs-UBPM
REM =================================================================
REM arg1 = start or stop.
REM arg2 = output dir.
REM arg3 = Maximum log file size in MB
REM arg4 = if boot mode is selected. (autosession\)

SETLOCAL ENABLEDELAYEDEXPANSION
for /f "usebackq tokens=*" %%i in (`powershell Get-Date -Format "yyyy-MMdd-HHmmss"`) do @set logdate=%%i
set tracelogdir=%2
set maxsize=%3
set boot=%4

if /i "%1" =="start" (

   logman ntfs_trace -ets > NUL 2>&1
   if !ERRORLEVEL! EQU 0 goto DEP

   ECHO Log folder is %tracelogdir%.
   ECHO Log size is %maxsize%.
   logman create trace "%boot%ntfs_trace" -ow -o %tracelogdir%\%COMPUTERNAME%_ntfs_trace_%logdate%.etl -p {B2FC00C4-2941-4D11-983B-B16E8AA4E25D} 0xffffffffffffffff 0xff -nb 16 16 -bs 1024 -mode Circular -f bincirc -max %maxsize% -ets
   logman update trace "%boot%ntfs_trace" -p {DD70BC80-EF44-421B-8AC3-CD31DA613A4E} 0xffffffffffffffff 0xff -ets
   logman update trace "%boot%ntfs_trace" -p {E9B319E4-0030-40A7-91CB-04D6A8EF7E09} 0xffffffffffffffff 0xff -ets
   logman update trace "%boot%ntfs_trace" -p {8E6A5303-A4CE-498F-AFDB-E03A8A82B077} 0xffffffffffffffff 0xff -ets

   if DEFINED boot (
      reg add HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\WMI\Autologger\ntfs_trace /v FileName /t REG_SZ /d "%tracelogdir%\%COMPUTERNAME%_boot_ntfs_trace.etl" /f
   )
   exit /b
) else if /i "%1" =="stop" (
   logman ntfs_trace -ets > NUL 2>&1
   if !ERRORLEVEL! EQU 0 (
      for /f "tokens=3 usebackq delims= " %%i in (`logman ntfs_trace -ets ^| findstr "Output Location"`) do (
         echo Logfile is %%i
      )
      logman stop "ntfs_trace" -ets
   )
   if DEFINED boot (
      logman delete "%boot%ntfs_trace"
   )
   echo Tracing has been stopped.
   exit /b
) else (
   goto USAGE
)

:DEP
   ECHO ntfs_trace has already been started.
exit /b

:USAGE
   ECHO   ntfs   collecting ntfs driver trace.
   ECHO   shacollector.bat trace ntfs start size [Maximum log file size in MB (default 4096 MB)] [output folder (default c:\mslog)]
   ECHO   shacollector.bat trace ntfs stop
   ECHO   Boot Option:
   ECHO   shacollector.bat trace ntfs boot size [Maximum log file size in MB (default 4096 MB)] [output folder (default c:\mslog)]
   ECHO   shacollector.bat trace ntfs delete

exit /b