REM =================================================================
REM refs     collecting ReFS drivers trace.
REM =================================================================
REM CD9C6198-BF73-4106-803B-C17D26559018 => Microsoft-Windows-ReFS
REM 740F3C34-57DF-4BAD-8EEA-72AC69AD5DF5 => RefsWppTrace
REM 059F0F37-910E-4FF0-A7EE-AE8D49DD319B => Microsoft-Windows-ReFS-v1
REM 6D2FD9C5-8BD8-4A5D-8AA8-01E5C3B2AE23 => Refsv1WppTrace
REM F9A81F79-369B-443C-9428-FC1DD98316F6 => Microsoft.Windows.FileSystem.ReFSUtil
REM 61D5C496-C69B-5B72-DE0A-29248A17CACE => RefsTelemetryProvider
REM 036647D2-2FB0-4E32-8349-3F5C19C16E5E => ReFS
REM =================================================================
REM arg1 = start or stop.
REM arg2 = output dir.
REM arg3 = Maximum log file size in MB
REM arg4 = if boot mode is selected. (autosession\)

SETLOCAL ENABLEDELAYEDEXPANSION
for /f "usebackq tokens=*" %%i in (`powershell Get-Date -Format "yyyy-MMdd-HHmmss"`) do @set logdate=%%i
set tracelogdir=%2
set maxsize=%3
set boot=%4

if /i "%1" =="start" (
   logman refs_trace -ets > NUL 2>&1
   if !ERRORLEVEL! EQU 0 goto DEP

   ECHO Log folder is %tracelogdir%.
   ECHO Log size is %maxsize%.
   logman create trace "%boot%refs_trace" -ow -o %tracelogdir%\%COMPUTERNAME%_refs_trace_%logdate%.etl -p {CD9C6198-BF73-4106-803B-C17D26559018} 0xffffffffffffffff 0xff -nb 16 16 -bs 1024 -mode Circular -f bincirc -max %maxsize% -ets
   logman update trace "%boot%refs_trace" -p {740F3C34-57DF-4BAD-8EEA-72AC69AD5DF5} 0xffffffffffffffff 0xff -ets
   logman update trace "%boot%refs_trace" -p {059F0F37-910E-4FF0-A7EE-AE8D49DD319B} 0xffffffffffffffff 0xff -ets
   logman update trace "%boot%refs_trace" -p {6D2FD9C5-8BD8-4A5D-8AA8-01E5C3B2AE23} 0xffffffffffffffff 0xff -ets
   logman update trace "%boot%refs_trace" -p {F9A81F79-369B-443C-9428-FC1DD98316F6} 0xffffffffffffffff 0xff -ets
   logman update trace "%boot%refs_trace" -p {61D5C496-C69B-5B72-DE0A-29248A17CACE} 0xffffffffffffffff 0xff -ets
   logman update trace "%boot%refs_trace" -p {036647D2-2FB0-4E32-8349-3F5C19C16E5E} 0xffffffffffffffff 0xff -ets

   if DEFINED boot (
      reg add HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\WMI\Autologger\refs_trace /v FileName /t REG_SZ /d "%tracelogdir%\%COMPUTERNAME%_boot_refs_trace.etl" /f
   )
   exit /b
) else if /i "%1" =="stop" (

   logman refs_trace -ets > NUL 2>&1
   if !ERRORLEVEL! EQU 0 (
      for /f "tokens=3 usebackq delims= " %%i in (`logman refs_trace -ets ^| findstr "Output Location"`) do (
         echo Logfile is %%i
      )
      logman stop "refs_trace" -ets
   )
   if DEFINED boot (
      logman delete "%boot%refs_trace"
   )
   echo Tracing has been stopped.
   exit /b
) else (
   goto USAGE
)

:DEP
   ECHO refs_trace has already been started.
exit /b

:USAGE
   ECHO   refs       collecting ReFS drivers trace.
   ECHO   shacollector.bat trace refs start size [Maximum log file size in MB (default 4096 MB)] [output folder (default c:\mslog)]
   ECHO   shacollector.bat trace refs stop
   ECHO   Boot Option:
   ECHO   shacollector.bat trace refs boot size [Maximum log file size in MB (default 4096 MB)] [output folder (default c:\mslog)]
   ECHO   shacollector.bat trace refs delete
exit /b

