REM =================================================================
REM storage   collecting storage drivers trace.
REM =================================================================
REM F96ABC17-6A5E-4A49-A3F4-A2A86FA03846 => StorVsp
REM 8B86727C-E587-4B89-8FC5-D1F24D43F69C => StorPort
REM 8E9AC05F-13FD-4507-85CD-B47ADC105FF6 => MPIO
REM DEDADFF5-F99F-4600-B8C9-2D4D9B806B5B => MSDSM
REM 1BABEFB4-59CB-49E5-9698-FD38AC830A91 => iSCSI
REM 945186BF-3DD6-4F3F-9C8E-9EDD3FC9D558 => Disk
REM FA8DE7C4-ACDE-4443-9994-C4E2359A9EDB => ClassPnP
REM 467C1914-37F0-4C7D-B6DB-5CD7DFE7BD5E => mountmgr
REM F5204334-1420-479B-8389-54A4A6BF6EF8 => volmgr
REM 0BEE3BC5-A50C-4EC3-A0E0-5AD11F2455A3 => partmgr
REM 67FE2216-727A-40CB-94B2-C02211EDB34A => volsnap
REM CB017CD2-1F37-4E65-82BC-3E91F6A37559 => volsnap (win10)
REM 3C70C3B0-2FAE-41D3-B68D-8F7FCAF79ADB => vhdmp
REM 6E580567-C67C-4B96-934E-FC2996E103AE => clusdisk
REM AB67B0F3-AE94-452D-B595-307667142420 => PmTelemetry
REM =================================================================
REM arg1 = start or stop.
REM arg2 = output dir.
REM arg3 = Maximum log file size in MB
REM arg4 = if boot mode is selected. (autosession\)

SETLOCAL ENABLEDELAYEDEXPANSION
for /f "usebackq tokens=*" %%i in (`powershell Get-Date -Format "yyyy-MMdd-HHmmss"`) do @set logdate=%%i
set tracelogdir=%2
set maxsize=%3
set boot=%4

if /i "%1" =="start" (

   logman storage_trace -ets > NUL 2>&1
   if !ERRORLEVEL! EQU 0 goto DEP

   ECHO Log folder is %tracelogdir%.
   ECHO Log size is %maxsize%.
   logman create trace "%boot%storage_trace" -ow -o %tracelogdir%\%COMPUTERNAME%_storage_trace_%logdate%.etl -p {F96ABC17-6A5E-4A49-A3F4-A2A86FA03846} 0xffffffffffffffff 0xff -nb 16 16 -bs 1024 -mode Circular -f bincirc -max %maxsize% -ets
   logman update trace "%boot%storage_trace" -p {8B86727C-E587-4B89-8FC5-D1F24D43F69C} 0xffffffffffffffff 0xff -ets
   logman update trace "%boot%storage_trace" -p {8E9AC05F-13FD-4507-85CD-B47ADC105FF6} 0xffffffffffffffff 0xff -ets
   logman update trace "%boot%storage_trace" -p {DEDADFF5-F99F-4600-B8C9-2D4D9B806B5B} 0xffffffffffffffff 0xff -ets
   logman update trace "%boot%storage_trace" -p {1BABEFB4-59CB-49E5-9698-FD38AC830A91} 0xffffffffffffffff 0xff -ets
   logman update trace "%boot%storage_trace" -p {945186BF-3DD6-4F3F-9C8E-9EDD3FC9D558} 0xffffffffffffffff 0xff -ets
   logman update trace "%boot%storage_trace" -p {FA8DE7C4-ACDE-4443-9994-C4E2359A9EDB} 0xffffffffffffffff 0xff -ets
   logman update trace "%boot%storage_trace" -p {467C1914-37F0-4C7D-B6DB-5CD7DFE7BD5E} 0xffffffffffffffff 0xff -ets
   logman update trace "%boot%storage_trace" -p {F5204334-1420-479B-8389-54A4A6BF6EF8} 0xffffffffffffffff 0xff -ets
   logman update trace "%boot%storage_trace" -p {0BEE3BC5-A50C-4EC3-A0E0-5AD11F2455A3} 0xffffffffffffffff 0xff -ets
   logman update trace "%boot%storage_trace" -p {67FE2216-727A-40CB-94B2-C02211EDB34A} 0xffffffffffffffff 0xff -ets
   logman update trace "%boot%storage_trace" -p {CB017CD2-1F37-4E65-82BC-3E91F6A37559} 0xffffffffffffffff 0xff -ets
   logman update trace "%boot%storage_trace" -p {3C70C3B0-2FAE-41D3-B68D-8F7FCAF79ADB} 0xffffffffffffffff 0xff -ets
   logman update trace "%boot%storage_trace" -p {6E580567-C67C-4B96-934E-FC2996E103AE} 0xffffffffffffffff 0xff -ets
   logman update trace "%boot%storage_trace" -p {AB67B0F3-AE94-452D-B595-307667142420} 0xffffffffffffffff 0xff -ets
   logman update trace "%boot%storage_trace" -p {96C57851-AF06-470F-8635-9C5E463E5F0C} 0xffffffffffffffff 0xff -ets

   if DEFINED boot (
      reg add HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\WMI\Autologger\storage_trace /v FileName /t REG_SZ /d "%tracelogdir%\%COMPUTERNAME%_boot_storage_trace.etl" /f
   )
   exit /b
) else if /i "%1" =="stop" (
   logman storage_trace -ets > NUL 2>&1
   if !ERRORLEVEL! EQU 0 (
      for /f "tokens=3 usebackq delims= " %%i in (`logman storage_trace -ets ^| findstr "Output Location"`) do (
         echo Logfile is %%i
      )
      logman stop "storage_trace" -ets
   )
   if DEFINED boot (
      logman delete "%boot%storage_trace"
   )
   echo Tracing has been stopped.
   exit /b
) else (
   goto USAGE
)

:DEP
   ECHO storage_trace has already been started.
exit /b

:USAGE
   ECHO   storage   collecting storage drivers trace.
   ECHO   shacollector.bat trace storage start size [Maximum log file size in MB (default 4096 MB)] [output folder (default c:\mslog)]
   ECHO   shacollector.bat trace storage stop
   ECHO   Boot Option:
   ECHO   shacollector.bat trace storage boot size [Maximum log file size in MB (default 4096 MB)] [output folder (default c:\mslog)]
   ECHO   shacollector.bat trace storage delete
exit /b