REM =================================================================
REM wsb       collecting Windows Server Backup modules trace. (Windows Server 2008 R2 or later)
REM =================================================================
REM 1DB28F2E-8F80-4027-8C5A-A11F7F10F62D => Microsoft-Windows-Backup
REM 5602C36E-B813-49D1-A1AA-A0C2D43B4F38 => wbengine
REM 4B966436-6781-4906-8035-9AF94B32C3F7 => SPP
REM 9138500E-3648-4EDB-AA4C-859E9F7B7C38 => VSS tracing provider
REM 67FE2216-727A-40CB-94B2-C02211EDB34A => volsnap
REM CB017CD2-1F37-4E65-82BC-3E91F6A37559 => volsnap (win10)
REM 3C70C3B0-2FAE-41D3-B68D-8F7FCAF79ADB => vhdmp
REM =================================================================
REM arg1 = start or stop.
REM arg2 = output dir.
REM arg3 = Maximum log file size in MB
REM arg4 = if boot mode is selected. (autosession\)

SETLOCAL ENABLEDELAYEDEXPANSION
for /f "usebackq tokens=*" %%i in (`powershell Get-Date -Format "yyyy-MMdd-HHmmss"`) do @set logdate=%%i
set tracelogdir=%2
set maxsize=%3
set boot=%4

if /i "%1" =="start" (
   logman wbengine_trace -ets > NUL 2>&1
   if !ERRORLEVEL! EQU 0 goto DEP

   ECHO Log folder is %tracelogdir%.
   ECHO Log size is %maxsize%.
   logman create trace "%boot%wbengine_trace" -ow -o %tracelogdir%\%COMPUTERNAME%_wbengine_trace_%logdate%.etl -p {1DB28F2E-8F80-4027-8C5A-A11F7F10F62D} 0xffffffffffffffff 0xff -nb 16 16 -bs 1024 -mode Circular -f bincirc -max %maxsize% -ets
   logman update trace "%boot%wbengine_trace" -p {5602C36E-B813-49D1-A1AA-A0C2D43B4F38} 0xffffffffffffffff 0xff -ets
   logman create trace "%boot%spp_trace" -ow -o %tracelogdir%\%COMPUTERNAME%_spp_trace_%logdate%.etl -p {4B966436-6781-4906-8035-9AF94B32C3F7} 0xffffffffffffffff 0xff -nb 16 16 -bs 1024 -mode Circular -f bincirc -max %maxsize% -ets
   logman create trace "%boot%vss_trace" -ow -o %tracelogdir%\%COMPUTERNAME%_vss_trace_%logdate%.etl -p {9138500E-3648-4EDB-AA4C-859E9F7B7C38} 0x00000fff 0xff -nb 16 16 -bs 1024 -mode Circular -f bincirc -max %maxsize% -ets
   logman create trace "%boot%volsnap_trace" -ow -o %tracelogdir%\%COMPUTERNAME%_volsnap_trace_%logdate%.etl -p {67FE2216-727A-40CB-94B2-C02211EDB34A} 0xffffffffffffffff 0xff -nb 16 16 -bs 1024 -mode Circular -f bincirc -max %maxsize% -ets
   logman update trace "%boot%volsnap_trace" -p {CB017CD2-1F37-4E65-82BC-3E91F6A37559} 0xffffffffffffffff 0xff -ets
   logman create trace "%boot%vhdmp_trace" -ow -o %tracelogdir%\%COMPUTERNAME%_vhdmp_trace_%logdate%.etl -p {3C70C3B0-2FAE-41D3-B68D-8F7FCAF79ADB} 0xffffffffffffffff 0xff -nb 16 16 -bs 1024 -mode Circular -f bincirc -max %maxsize% -ets

   if DEFINED boot (
      reg add HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\WMI\Autologger\wbengine_trace /v FileName /t REG_SZ /d "%tracelogdir%\%COMPUTERNAME%_boot_wbengine_trace.etl" /f
      reg add HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\WMI\Autologger\spp_trace /v FileName /t REG_SZ /d "%tracelogdir%\%COMPUTERNAME%_boot_spp_trace.etl" /f
      reg add HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\WMI\Autologger\vss_trace /v FileName /t REG_SZ /d "%tracelogdir%\%COMPUTERNAME%_boot_vss_trace.etl" /f
      reg add HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\WMI\Autologger\volsnap_trace /v FileName /t REG_SZ /d "%tracelogdir%\%COMPUTERNAME%_boot_volsnap_trace.etl" /f
      reg add HKEY_LOCAL_MACHINE\SYSTEM\CurrentControlSet\Control\WMI\Autologger\vhdmp_trace /v FileName /t REG_SZ /d "%tracelogdir%\%COMPUTERNAME%_boot_vhdmp_trace" /f
   )
   exit /b
) else if /i "%1" =="stop" (
   logman wbengine_trace -ets > NUL 2>&1
   if !ERRORLEVEL! EQU 0 (
      for /f "tokens=3 usebackq delims= " %%i in (`logman wbengine_trace -ets ^| findstr "Output Location"`) do (
         echo Logfile is %%i
      )
      logman stop "wbengine_trace" -ets

      for /f "tokens=3 usebackq delims= " %%i in (`logman spp_trace -ets ^| findstr "Output Location"`) do (
         echo Logfile is %%i
      )
      logman stop "spp_trace" -ets

      for /f "tokens=3 usebackq delims= " %%i in (`logman vss_trace -ets ^| findstr "Output Location"`) do (
         echo Logfile is %%i
      )
      logman stop "vss_trace" -ets

      for /f "tokens=3 usebackq delims= " %%i in (`logman volsnap_trace -ets ^| findstr "Output Location"`) do (
         echo Logfile is %%i
      )
      logman stop "volsnap_trace" -ets

      for /f "tokens=3 usebackq delims= " %%i in (`logman vhdmp_trace -ets ^| findstr "Output Location"`) do (
         echo Logfile is %%i
      )
      logman stop "vhdmp_trace" -ets
   )
   if DEFINED boot (
      logman delete "%boot%wbengine_trace"
      logman delete "%boot%spp_trace"
      logman delete "%boot%vss_trace"
      logman delete "%boot%volsnap_trace"
      logman delete "%boot%vhdmp_trace"
   )
   echo Tracing has been stopped.
   exit /b
) else (
   goto USAGE
)
:DEP
   ECHO wbengine_trace has already been started.
exit /b

:USAGE
   ECHO   wsb       collecting Windows Server Backup modules trace. (Windows Server 2008 R2 or later)
   ECHO   shacollector.bat trace wsb stop
   ECHO   Boot Option:
   ECHO   shacollector.bat trace wsb boot
   ECHO   shacollector.bat trace wsb delete
exit /b