@echo off

REM
REM shacollector (Storage and High Availability area log collection tool)
REM Copyright (C) 2018-2019 Microsoft All Rights Reserved.

SETLOCAL ENABLEDELAYEDEXPANSION
for /f "usebackq tokens=*" %%i in (`powershell Get-Date -Format "yyyy-MMdd-HHmmss"`) do @set logdate=%%i
SET basedir=c:\mslog
SET libdir=%~d0%~p0libs
SET scriptdir=%~d0%~p0libs\script
SET logdir=
SET scriptlogdir=%~d0%~p0logs
SET sample-interval=00:00:15
SET retention-days=3
SET maxsize=
SET trace-maxsize=4096
SET xperf-maxsize=8192
SET eulamode=0
SET readme=%~d0%~p0ReadMe.md
SET pspolicy=

for /f "tokens=2" %%A in ('findstr Version: %~dp0\ReadMe.md') do SET version=%%A

md %scriptlogdir% > NUL 2>&1
REM =================================================================
REM Administrator authority check.
openfiles > NUL 2>&1
if NOT %ERRORLEVEL% EQU 0 goto NotAdmin
REM =================================================================

REM =================================================================
REM Unblock script files in shacollector. (delete Zone.Identifier stream)
if NOT EXIST %scriptlogdir%\unblocked (
   powershell "Get-ChildItem %~dp0 -Recurse | Unblock-File"
   echo unblocked > %scriptlogdir%\unblocked
)
REM =================================================================

REM =================================================================
REM check powershell execution policy
for /f "usebackq tokens=*" %%i in (`powershell Get-Executionpolicy`) do @set pspolicy=%%i

if /i "%pspolicy%" =="Restricted" (
   powershell.exe Set-ExecutionPolicy -ExecutionPolicy RemoteSigned
)
REM =================================================================

REM =================================================================
REM check EULA
for %%i in (%*) do (
   if /i "%%i" =="accepteula" (
      set eulamode=2
   )
)
powershell.exe -File %LIBDIR%\checkEULA.ps1 %~n0 %eulamode% -executionpolicy remotesigned;exit $LASTEXITCODE
if NOT %ERRORLEVEL% EQU 0 goto EXIT
REM =================================================================

REM =================================================================
REM Check Arguments.
REM =================================================================
set TRACE=FALSE
set PERF=FALSE
set SUPPORT=FALSE
set PERFMON=FALSE
set POOLTAG=FALSE

if "%1" == "" goto USAGE
if /i "%1" =="perf" (
   set PERF=TRUE
   set scriptdir=%scriptdir%\perf
) else if /i "%1" =="trace" (
   set TRACE=TRUE
   set scriptdir=%scriptdir%\traces
) else if /i "%1" =="support" (
   set SUPPORT=TRUE
   set scriptdir=%scriptdir%\support
) else (
   goto USAGE
)

if %SUPPORT%==TRUE (
   set output=%~f3
   if "!output!" == "" (
      if NOT EXIST !basedir! (
         md !basedir!
         if NOT !ERRORLEVEL! EQU 0 goto ERROR
      )
      set logdir=!basedir!\supportlog-%logdate%
   ) else (
      if /i EXIST !output! (
         pushd !output!
         if NOT !ERRORLEVEL! EQU 0 goto ERROR
         popd
      ) else (
         md !output!
         if NOT !ERRORLEVEL! EQU 0 goto ERROR
         pushd !output!
         if NOT !ERRORLEVEL! EQU 0 goto ERROR
         popd
      )
      set logdir=!output!\supportlog-%logdate%
   )
   if NOT EXIST !supportlogdir! (
      md !logdir!
      if NOT !ERRORLEVEL! EQU 0 goto ERROR
   )
   echo Log folder is !logdir!
   if EXIST !scriptdir!\%2.txt (
      for /f %%a in (!scriptdir!\%2.txt) do (
         if EXIST !scriptdir!\%%a.bat (
            echo %2 > !logdir!\option.txt
            call !scriptdir!\%%a.bat !logdir!\%%a
	    echo %version% >> !logdir!\option.txt
       echo %date% >> !logdir!\option.txt
       echo %time% >> !logdir!\option.txt
         )
      )
   ) else if EXIST !scriptdir!\%2.bat (
      call !scriptdir!\%2.bat !logdir!\%2
   ) else (
      goto USAGE
   )
   goto EXIT
) else if %TRACE%==TRUE (

   if /i "%4" =="size" (
      set maxsize=%5
      set output=%~f6
   ) else (
      set output=%~f4

      if /i "%2" =="psr" (
         set maxsize=10
      ) else (
         set maxsize=%trace-maxsize%
      )
   )

   if /i "%3" =="boot" (
      set boot=autosession\
      set START_OR_STOP=start
      goto START
   ) else if /i "%3" =="start" (
      set START_OR_STOP=start
      goto START
   ) else if /i "%3" =="delete" (
      set boot=autosession\
      set START_OR_STOP=stop
      goto STOP
   ) else if /i "%3" =="stop" (
      set START_OR_STOP=stop
      goto STOP      
   ) else (
      goto USAGE
   )
) else if %PERF%==TRUE (
   if /i "%4" =="size" (
      set maxsize=%5
      set output=%~f6
   ) else (
      set output=%~f4
      set maxsize=%xperf-maxsize%
   )
   if /i "%3" =="start" (
      set START_OR_STOP=start

      if /i "%2" =="perfmon" (
         set PERFMON=TRUE
         if /i "%4" =="interval" (
            if /i "%6" =="days" (
               set retention-days=%7
            ) 
            set sample-interval=%5
            set output=%basedir%
            goto START

         ) else if /i "%4" == "days" (
            set retention-days=%5
            set output=%basedir%
            goto START

         ) else if /i "%5" =="interval" (
            if /i "%7" =="days" (
               set retention-days=%8
            )
            set sample-interval=%6
            set output=%~f4
            goto START

         ) else if /i "%5" =="days" (
            set retention-days=%6
            set output=%~f4
            goto START

         ) else if /i "%4" =="" (
            set output=%basedir%
            goto START
         ) else (
            set output=%~f4
            goto START
         )

      ) else if /i "%2" =="memory" (
         if /i "%4" =="tag" (
            set POOLTAG=TRUE
            set tagname=%5
            set output=%basedir%
            goto START
         ) else if /i "%5" =="tag" (
            set POOLTAG=TRUE
            set tagname=%6
            set output=%~f4
            goto START
         ) else if /i "%6" =="tag" (
            set POOLTAG=TRUE
            set tagname=%7
            set output=%basedir%
            goto START
         ) else if /i "%7" =="tag" (
            set POOLTAG=TRUE
            set tagname=%8
            set output=%~f6
            goto START
         ) else if /i "%4" =="" (
            set output=%basedir%
            set tagname=
            goto START
         ) else (
            set tagname=
            goto START
         )
      ) else if /i "%2" =="heap" (
         if /i "%4" == "PID" (
             set PID=%5
             set ENABLE_OR_SNAP=%6
             set output=%basedir%
             goto START
         ) else if /i "%5" == "PID" (
             set PID=%6
             set ENABLE_OR_SNAP=%7
             set output=%4
             goto START
         )
      ) else ( 
         goto START
      )
   ) else if /i "%3" =="stop" (
      set START_OR_STOP=stop
      goto STOP  
   ) else (
      goto USAGE
   )
) else (
   goto USAGE
)

:START
if "!output!" == "" (
   if NOT EXIST !basedir! (
      md !basedir!
      if NOT !ERRORLEVEL! EQU 0 goto ERROR
   )
   if "%3" =="boot" (
      set logdir=!basedir!\%3
   ) else (
      set logdir=!basedir!\%1
   )
) else (
   if /i EXIST !output! (
      pushd !output!
      if NOT !ERRORLEVEL! EQU 0 goto ERROR
      popd
   ) else (
      md !output!
      if NOT !ERRORLEVEL! EQU 0 goto ERROR
      pushd !output!
      if NOT !ERRORLEVEL! EQU 0 goto ERROR
      popd
   )
      
   if "%3" =="boot" (
      set logdir=!output!\%3
   ) else (
      set logdir=!output!\%1
   )
)

if NOT EXIST !logdir! (
   md !logdir!
   if NOT !ERRORLEVEL! EQU 0 goto ERROR
)
REM ECHO Log folder is !logdir!

if %PERF%==TRUE (
   echo !logdir! > %scriptlogdir%\%1_%2_logdir.txt
)
goto RUN

:STOP
if %TRACE%==TRUE (
   REM temporary specified for TRACE stopping.
   set logdir=%scriptlogdir%
   goto RUN
) else if %PERF%==TRUE (
   if EXIST %scriptlogdir%\%1_%2_logdir.txt (
      for /f %%a in (%scriptlogdir%\%1_%2_logdir.txt) do (
         set logdir=%%a
         del %scriptlogdir%\%1_%2_logdir.txt
      )
   ) else (
      ECHO can not find %scriptlogdir%\%1_%2_logdir.txt.
      ECHO Maybe %1 %2 is not running.
      goto ERROR
   )
   goto RUN
) else (
  goto USAGE
)

:RUN
ECHO %2 %3 collecting.
if EXIST !scriptdir!\%2.bat (
   if !PERFMON!==TRUE (
      call !scriptdir!\%2.bat %START_OR_STOP% !logdir! %sample-interval% %retention-days%
   ) else if !POOLTAG!==TRUE (
      call !scriptdir!\%2.bat %START_OR_STOP% !logdir! !maxsize! %tagname%
   ) else if %2 == heap (
      call !scriptdir!\%2.bat %PID% %ENABLE_OR_SNAP% !logdir!
   ) else (
     call !scriptdir!\%2.bat %START_OR_STOP% !logdir! !maxsize! !boot!
   )
   goto EXIT
) else (
   goto USAGE
)

:USAGE
ECHO shacollector (Storage and High Availability area log collection tool) 
ECHO Usage:
ECHO   shacollector.bat trace [trace option] start size [Maximum log file size in MB (default 4096 MB)] [output folder (default c:\mslog)]
ECHO   shacollector.bat trace [trace option] stop
ECHO   shacollector.bat trace [trace option] boot size [Maximum log file size in MB (default 4096 MB)] [output folder (default c:\mslog)]
ECHO   shacollector.bat trace [trace option] delete
ECHO.
ECHO   shacollector.bat perf perfmon start [output folder (default c:\mslog)] interval [sample interval [hh:mm:ss] (ex. 00:00:15) default 15sec] days [retention days (default 3 days)]
ECHO   shacollector.bat perf cpu start size [Maximum log file size in MB (default 8192 MB)] [output folder (default c:\mslog)]
ECHO   shacollector.bat perf cpu stop
ECHO   shacollector.bat perf memory start size [Maximum log file size in MB (default 8192 MB)] [output folder (default c:\mslog)] tag "POOL TAG (ex. FMfn)"
ECHO   shacollector.bat perf memory stop
ECHO   shacollector.bat perf disk start size [Maximum log file size in MB (default 8192 MB)] [output folder (default c:\mslog)]
ECHO   shacollector.bat perf disk stop
ECHO   shacollector.bat perf delay start size [Maximum log file size in MB (default 8192 MB)] [output folder (default c:\mslog)]
ECHO   shacollector.bat perf delay stop
ECHO   shacollector.bat perf heap start pid "Process ID (ex. 1234)" enable
ECHO   shacollector.bat perf heap start [output folder (default c:\mslog)] pid "Process ID (ex. 1234)" snap
ECHO   shacollector.bat perf heap stop
ECHO   shacollector.bat perf boot start [output folder (default c:\mslog)] 
ECHO   shacollector.bat perf boot stop
ECHO.
ECHO   shacollector.bat support all [output folder (default c:\mslog)]
ECHO   shacollector.bat support basic [output folder (default c:\mslog)]
ECHO   shacollector.bat support nomsinfo [output folder (default c:\mslog)]
ECHO   shacollector.bat support [supportlog option] [output folder (default c:\mslog)]

ECHO.
ECHO   more detail, plase check %readme% file.
goto EXIT

:NotAdmin
ECHO Please run as Administrator authority.
goto EXIT

:ERROR
goto EXIT

:EXIT
REM =================================================================
REM reset powershell execution policy if it was Restricted policy.
if /i "%pspolicy%" =="Restricted" (
   powershell.exe Set-ExecutionPolicy -ExecutionPolicy Restricted
)
REM =================================================================

ENDLOCAL
exit /b